@@ -107,6 +107,9 @@ class ChemicalReaction(Entity):
         if 'Safety' not in finalProperties:
             finalProperties['Safety'] = {}
 
+        if (equivalents):
+            equivalents = str(equivalents)
+
         params = {
             "type": type,
             "equivalence": equivalents,
