@@ -1,9 +1,10 @@
 
 from labstep.entities.experimentSignatureRequest.model import ExperimentSignatureRequest
 import labstep.generic.entity.repository as entityRepository
+from labstep.constants import UNSPECIFIED
 
 
-def newExperimentSignatureRequest(user, experiment_id, user_id, message=None):
+def newExperimentSignatureRequest(user, experiment_id, user_id, message=UNSPECIFIED):
     fields = {
         "experiment_workflow_id": experiment_id,
         "message": message,
