@@ -8,7 +8,7 @@ from labstep.constants import UNSPECIFIED
 
 
 class ExperimentStep(EntityWithComments):
-    __entityName__ = "experiment-step"
+    __entityName__ = "protocol-step"
 
     def edit(self, completed_at=UNSPECIFIED):
         """
